==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/getewertvbextfilteru.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getewertvbextfilteru//
create function getewertvbextfilteru(wid integer, von datetime(6), bis datetime(6),
  mode varchar(12), zvon time, zbis time, wtf varchar(20),
  vg1 varchar(3), wf1 varchar(250),
  m2 varchar(3), vg2 varchar(3), wf2 varchar(250),
  m3 varchar(3), vg3 varchar(3), wf3 varchar(250),
  m4 varchar(3), vg4 varchar(3), wf4 varchar(250), neh varchar(100))
                  returns varchar(30)
deterministic
sql security invoker
begin
  declare r, l double;
  declare ld datetime(6);
  declare va, ba, vo, bo time;
  declare f integer;

  if TIME(zvon) < TIME(zbis)
   then
    set va = TIME(zvon);
    set ba = TIME(zbis);
    set vo = '24:00:00';
    set bo = '-00:00:01';
  else
    set va = '24:00:00';
    set ba = '-00:00:01';
    set vo = TIME(zvon);
    set bo = TIME(zbis);
  end if;
  case mode
    when 'min' then
      select min(ehwconv(wert, neh)+0) from twerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
          ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      into r;
    when 'max' then
      select max(ehwconv(wert, neh)+0) from twerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
          ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      into r;
    when 'avg' then
      select avg(ehwconv(wert, neh)+0) from twerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
          ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      into r;
    when 'last/avg' then
      select ehwconv(wert, neh)+0, datum from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
        order by datum desc limit 1 into l, ld;
      select avg(ehwconv(wert, neh)+0) from twerte
      where werteindizesID = wid and von <= datum and datum < ld
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
          ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      into r;
      if r != 0 then
        return l/r;
      else
        return '';
      end if;
    when 'last/avg-1' then
      select ehwconv(wert, neh)+0, datum from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
        order by datum desc limit 1 into l, ld;
      select avg(ehwconv(wert, neh)+0) from twerte
      where werteindizesID = wid and von <= datum and datum < ld
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
          ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      into r;
      if r != 0 then
        return l/r-1;
      else
        return '';
      end if;
    when 'dev' then
      select stddev_samp(ehwconv(wert, neh)+0) from twerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
          ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      into r;
    when 'sum' then
      select sum(ehwconv(wert, neh)+0) from twerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
          ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      into r;
    when 'max-min' then
      select max(ehwconv(wert, neh)+0)-min(ehwconv(wert, neh)+0) from twerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
          ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      into r;
    when 'last-first' then
      return (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum desc limit 1)
           - (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum limit 1);
    when 'last-first+' then
      set r = (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum desc limit 1)
           - (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum limit 1);
      if r < 0 then
        return '';
      end if;
    when 'last-first-' then
      set r = (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum desc limit 1)
           - (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum limit 1);
      if r > 0 then
        return '';
      end if;
    when 'first' then
      select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum limit 1
      into r;
    when 'differ' then
      return BINARY (select wert from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum desc limit 1)
          != BINARY (select wert from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum limit 1);
    when 'count' then
      select count(*) from twerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
          ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      into r;
    when 'grad' then
      return gradientevbextfilter(wid, von, bis, zvon, zbis, wtf,
              vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4, neh);
    when 'accel' then
      return accele(wid, von, bis, zvon, zbis, wtf,
              vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4, neh);
    when 'last' then
      select ehwconv(wert, neh) from twerte
      where werteindizesID = wid and von <= datum and datum <= bis
        and ((va <= TIME(datum) and TIME(datum) <= ba)
             or vo <= TIME(datum) or TIME(datum) <= bo)
        and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
        and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
          ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      order by datum desc limit 1
      into r;
    else
      return '';
  end case;
  return r;
end//

GRANT EXECUTE on FUNCTION getewertvbextfilteru
   to logginglesen@'localhost', loggingtest@'localhost', loggingadmin@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/getewertvbextfilteru.sql <==
-- getewertvbextfilteru.sql
--
-- function getewertvbextfilteru(wid, von, bis, mode, zvon, zbis, wtf, vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4, neh) returns varchar
-- wid: werteindizesID
-- von: datetime from
-- bis: datetime to
-- mode: aggregation function
-- zvon: time from
-- zbis: time to
-- wtf: set of weekdays
-- vg1: comparevalue 1
-- wf1: comparefunction 1
-- m2: OR|AND
-- vg2: comparevalue 2
-- wf2: comparefunction 2
-- m3: OR|AND
-- vg3: comparevalue 3
-- wf3: comparefunction 3
-- m4: OR|AND
-- vg4: comparevalue 4
-- wf4: comparefunction 4
-- neh: unit for output
-- return: aggragated value with extended filter unit '[E]'

set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS getewertvbextfilteru//
create function getewertvbextfilteru(wid integer, von datetime(6), bis datetime(6),
  mode varchar(12), zvon time, zbis time, wtf varchar(20),
  vg1 varchar(3), wf1 varchar(250),
  m2 varchar(3), vg2 varchar(3), wf2 varchar(250),
  m3 varchar(3), vg3 varchar(3), wf3 varchar(250),
  m4 varchar(3), vg4 varchar(3), wf4 varchar(250), neh varchar(20))
                  returns varchar(30)
deterministic
sql security invoker
begin
  declare r, l double;
  declare ld datetime(6);
  declare va, ba, vo, bo time;
  declare f integer;

  if TIME(zvon) < TIME(zbis)
   then
    set va = TIME(zvon);
    set ba = TIME(zbis);
    set vo = '24:00:00';
    set bo = '-00:00:01';
  else
    set va = '24:00:00';
    set ba = '-00:00:01';
    set vo = TIME(zvon);
    set bo = TIME(zbis);
  end if;
  case mode
    when 'min' then
      select min(ehwconv(wert, neh)+0) into r from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh));
    when 'max' then
      select max(ehwconv(wert, neh)+0) into r from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh));
    when 'avg' then
      select avg(ehwconv(wert, neh)+0) into r from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh));
    when 'last/avg' then
      select ehwconv(wert, neh)+0, datum into l, ld from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
        order by datum desc limit 1;
      select avg(ehwconv(wert, neh)+0) into r from twerte
        where werteindizesID = wid and von <= datum and datum < ld
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh));
      if r != 0 then
        return l/r;
      else
        return '';
      end if;
    when 'last/avg-1' then
      select ehwconv(wert, neh)+0, datum into l, ld from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
        order by datum desc limit 1;
      select avg(ehwconv(wert, neh)+0) into r from twerte
        where werteindizesID = wid and von <= datum and datum < ld
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh));
      if r != 0 then
        return l/r-1;
      else
        return '';
      end if;
    when 'dev' then
      select stddev_samp(ehwconv(wert, neh)+0) into r from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh));
    when 'sum' then
      select sum(ehwconv(wert, neh)+0) into r from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh));
    when 'max-min' then
      select max(ehwconv(wert, neh)+0)-min(ehwconv(wert, neh)+0) into r from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh));
    when 'last-first' then
      return (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum desc limit 1)
           - (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum limit 1);
    when 'last-first+' then
      set r = (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum desc limit 1)
           - (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum limit 1);
      if r < 0 then
        return '';
      end if;
    when 'last-first-' then
      set r = (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum desc limit 1)
           - (select ehwconv(wert, neh) from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum limit 1);
      if r > 0 then
        return '';
      end if;
    when 'first' then
      select ehwconv(wert, neh) into r from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
            ehwconv(wf4, neh))
        order by datum limit 1;
    when 'differ' then
      return BINARY (select wert from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum desc limit 1)
          != BINARY (select wert from twerte
              where werteindizesID = wid and von <= datum and datum <= bis
                and ((va <= TIME(datum) and TIME(datum) <= ba)
                     or vo <= TIME(datum) or TIME(datum) <= bo)
                and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
                and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
                  ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4,
                  ehwconv(wf4, neh))
              order by datum limit 1);
    when 'count' then
      select count(*) into r from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh));
    when 'grad' then
      return gradientevbextfilter(wid, von, bis, zvon, zbis, wtf,
              vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4, neh);
    when 'accel' then
      return accele(wid, von, bis, zvon, zbis, wtf,
              vg1, wf1, m2, vg2, wf2, m3, vg3, wf3, m4, vg4, wf4, neh);
    when 'last' then
      select ehwconv(wert, neh) into r from twerte
        where werteindizesID = wid and von <= datum and datum <= bis
          and ((va <= TIME(datum) and TIME(datum) <= ba)
               or vo <= TIME(datum) or TIME(datum) <= bo)
          and (wtf = '' or find_in_set(DAYOFWEEK(datum), wtf))
          and extfilter(ehwconv(wert, neh), vg1, ehwconv(wf1, neh), m2, vg2,
            ehwconv(wf2, neh), m3, vg3, ehwconv(wf3, neh), m4, vg4, ehwconv(wf4, neh))
      order by datum desc limit 1;
    else
      return '';
  end case;
  return r;
end//

GRANT EXECUTE on FUNCTION getewertvbextfilteru
   to logginglesen@'localhost', loggingtest@'localhost', loggingadmin@'localhost'//
